#
# spec file for package alacarte
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           alacarte
Version:        3.54.0
Release:        1.2
Summary:        Menu editor for GNOME
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/GNOME/alacarte
Source:         %{name}-%{version}.tar.zst

BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  glib2-devel
BuildRequires:  libtool
# Needed for the typelib() dependency parser
BuildRequires:  gobject-introspection
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3 >= 3.3
BuildRequires:  suse-xsl-stylesheets
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libgnome-menu-3.0) >= 3.5.3
BuildRequires:  pkgconfig(pygobject-3.0)
Requires:       python3-gobject-Gdk
BuildArch:      noarch

%description
Alacarte is a simple freedesktop.org compliant menu editor for GNOME
that lets you change your menus, simply and quickly. Just click and
type to edit, add, and delete any menu entry.

%lang_package

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure
%make_build

%install
%make_install
%suse_update_desktop_file -r alacarte GNOME Utility DesktopUtility X-GNOME-PersonalSettings
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

# If ChangeLog is empty, don't package it.
if test -s ChangeLog; then
    install -p -m 0644 -D ChangeLog \
      %{buildroot}%{_defaultdocdir}/Alacarte/ChangeLog
else
    rm -f ChangeLog
fi

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/alacarte
%{_datadir}/alacarte
%{_datadir}/applications/alacarte.desktop
%{_datadir}/metainfo/org.gnome.alacarte.metainfo.xml
%{_datadir}/icons/hicolor/
%{python3_sitelib}/Alacarte
%{_mandir}/man1/alacarte.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Oct 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.54.0:
  + Show only images in icon picker.
  + Add AppStream metadata.
  + Updated translations.
- Convert to obs_scm source service for easier updating.
- Add libtool BuildRequires and call autogen.sh: the git checkout
  is not bootstrapped.
* Mon Aug 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire gettext-devel instead of gettext: allow OBS to
  shortcut through gettext-runtime-mini.
* Thu Mar 21 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.52.0:
  + Updated translations.
* Sun Sep 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.50.0:
  + Updated translations.
* Sun Jul 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.44.3:
  + Updated translations.
* Mon Jun 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.44.2:
  + Fix launcher saving.
  + Updated translations.
* Wed Mar 23 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 3.44.1:
  + Updated translations.
- Replace intltool build requirement with gettext to follow
  upstream changes.
- Add a shell construct to check whether the ChangeLog file size is
  zero or not. If it's zero, we don't package the file, but remove
  it.
* Mon Mar 21 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 3.44.0:
  + Resync command line validity on focus gained
    (glgo#GNOME/alacarte#10).
  + Fix icon changing (glgo#GNOME/alacarte#13).
  + Updated translations.
- Drop no longer needed hicolor-icon-theme build requirement. It
  was only being required for the icon_theme_cache_post(un) macros,
  which, by the way, have been replaced by RPM file trigger
  facilities.
- Bump Python minimal build requirement version from 3.2 to 3.3
  aligning with configure build script checks.
* Mon Jan 10 2022 Yifan Jiang <yfjiang@suse.com>
- Add python-rpm-macros BuildRequires in case some build
  environment does not pull it automatically. This is needed by
  macros like %%{python3_sitelib}.
* Tue Nov 23 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.42.0:
  + Fix icon size in launcher properties window
  + Resize input field with launcher dialog
  + Support Python 3.10+
  + Updated translations.
- Drop alacarte-trans.patch: No longer needed as we do not use
  translation-update-upstream any more.
- Modernize spec, fixup fdupes call, build as noarch.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Apr 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed broken upstream URL in SPEC file
* Thu Mar  5 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Require Python 3.2+.
* Fri Feb 14 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Fix bad command validation.
  + Require Python 3.0+.
  + Support Python 3.8+.
- Drop fix-bad-command-validation.patch and alacarte-python3.patch:
  fixed upstream.
- Drop autoconf and automake BuildRequires, and no longer call
  autoreconf: no patch touches the build system.
- Rebase alacarte-trans.patch.
- Drop deprecated use of %%desktop_database_post/postun and
  - %%icon_theme_cache_post/postun macros.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Jan 29 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Update alacarte-python3.patch: Add support for python 3.7.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Jan 15 2018 mgorse@suse.com
- Migrate to python3 (bsc#1075771):
  + Add alacarte-python3.patch: convert the code to be py3
    compatible.
  + Update alacarte-trans.patch: Don't use tab for indentation.
  + Add autoconf and automake BuildRequires and call autoreconf in
    build section: needed, since above patches touch the build
    system.
  + Replace python BuildRequires with python3.
  + Add python3-gobject-Gdk Requires: new dependency.
* Thu Sep 14 2017 qzheng@suse.com
- Added fix-bad-command-validation.patch which fix bad command
  validation, backported from commit hash 665b471 and ca7d05c
  (bsc#1057908, bgo#728372).
* Fri May 20 2016 alarrosa@suse.com
- Update to GNOME 3.20.2 (Fate#318572)
* Tue May  3 2016 dimstar@opensuse.org
- Require python-gobject-Gdk: pygobject was further split in order
  to be able to install it without X-dependencies. Alacarte imports
  Gdk from gi.repository, thus also requires python-gobject-Gdk.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Fri Nov 27 2015 qzhao@suse.org
- Updated alacarte-trans.patch to modify alacarte.ui:
  use original text, translate all PO tranlation files.
  Modified under Stanislav Brabec's review result.
  (bnc#947793)
* Tue Oct 13 2015 qzhao@suse.org
- Added alacarte-trans.patch which adds a gettext function
  to ItemEditor.py to make alacarte translatable (bnc#947793)
* Sun Oct  5 2014 zaitor@opensuse.org
- Move .desktopfile from X-GNOME-SystemSettings to
  X-GNOME-PersonalSettings, since the only values one can change is
  for active user. Having it under System gives the impression that
  changes are systemwide.
* Sat Aug  9 2014 dimstar@opensuse.org
- Add X-GNOME-SystemSettings to the .desktop categories: this adds
  allacarte to the overview in gnome-control-center.
* Mon Mar  3 2014 zaitor@opensuse.org
- Update to version 3.11.91:
  + Drop Help button.
  + Ensure items have valid Exec.
  + Add a man page.
  + Make Restore button work again.
  + Fix creating menus.
  + Fix creating items.
  + Updated translations.
- Drop alacarte-nohelp.patch, fixed upstream.
- Add suse-xsl-stylesheets BuildRequires, needed to build manpages.
* Thu Dec 12 2013 dimstar@opensuse.org
- Drop alacarte_system_edit_mode.patch: after almost 5 year needing
  rebase, the feature can't possible be important enough.
* Sat Sep 28 2013 dimstar@opensuse.org
- Correct alacarte-nohelp.patch: only remove the accelerator,
  nothing else (bnc#842988).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Errors on launch.
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Fix Unicode/binary screwups causing UnicodeDecodeErrors.
  + Add python3 compatibility.
  + Don't leave behind stale .desktop files.
  + Actually quit when hitting the close button.
* Thu Feb 28 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Remove dependency on gnome-panel by rewriting the menu/item
    editor.
  + Cleanups to the UI.
  + Allow editing menus other than applications.menu.
  + Updated translations.
- Drop alacarte-desktop.patch: fixed upstream.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Enforce the use of Gtk3 (bgo#691599)
  + Allow specifying a menu basename other than applications.menu.
  + Updated translations.
- Drop alacarte-force-Gtk3.patch: fixed upstream.
- Drop alacarte-support-exo-desktop-item-edit.patch: no longer
  applicable, as an internal menu editor is now being used.
- Add alacarte-desktop.patch: fix a typo which avoided the
  installation of the .desktop file.
* Sun Jan 13 2013 zaitor@opensuse.org
- Update to version 3.7.2:
  + Deal with the case of having no $XDG_MENU_PREFIX
  + Fix some crashes when writing out unicode files.
  + Misc cleanups
  + Updated translations.
- Rebase alacarte-force-Gtk3.patch.
* Sat Jan 12 2013 dimstar@opensuse.org
- Add alacarte-force-Gtk3.patch: Force the use of Gtk 3. Gtk2 was
  not designed for use with introspection and some interfaces fail
  (bnc#798181, bgo#691599).
* Wed Oct 17 2012 zaitor@opensuse.org
- Update to version 3.6.1:
  + Bugs Fixed: Respect $XDG_MENU_PREFIX.
  + Updated translations.
- Drop alacarte-xdg-menu.patch, fixed upstream.
- Drop %%if check for obsolete openSUSE version.
* Thu Sep  6 2012 dimstar@opensuse.org
- Add alacarte-xdg-menu.patch: Use XDG_MENU_PREFIX when referencing
  applications.menu (bnc#779098).
* Thu Sep  6 2012 dimstar@opensuse.org
- Add alacarte-nohelp.patch: Do not show a help button or act on
  F1 key: there is no help in alacarte at this moment (bnc#779062).
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Fix the "Revert" button
  + Updated translations.
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Code cleanups
  + Renamed the "Revert" button, hopefully to make it less
    confusing
  + Updated translations.
* Wed Jun 27 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Bugs fixed:
  - Code cleanups
  - Don't fail when loading a non-existant icon
  - Fix spurious crashes and asserts by removing the visible_tree
    stuff
  - Fix separator support (bgo#677343)
  - Put back the top-level "Applications" section that was
    accidentally removed (bgo#677420)
  + Updated translations.
- Rebase alacarte-support-exo-desktop-item-edit.patch.
* Wed Jun  6 2012 dimstar@opensuse.org
- Update to version 0.13.4:
  + Remove old PyGTK+/PyGObject 2 version checks (bgo#676699)
  + Crash on exit due to a NULL tree-view selection (bgo#676702)
  + Avoid crashing if a .desktop file has no icon defined
    (bgo#676700)
  + Mark Alacarte as a Utility (bgo#658880)
  + Unable to rearrange menu items (bgo#676987)
  + Various code cleanups
  + MainWindow: Don't select the destination folder after a drop
    (bgo#551390)
  + Don't fail when handed corrupt or invalid XML (bgo#654167)
- Changes from version 0.13.3:
  + Port to GI introspection
- Update BuildRequires after port to GI Introspection:
  + Removed: python-gtk, pkgconfig(libgnome-menu),
  + Added: pkgconfig(libgnome-menu-3.0), pkgconfig(pygobject-3.0)
- Drop no longer needed Requires: python-gnome-menus, python-gtk:
  after the port to GI Introspection, we are able to auto-detect
  the needed requires.
- Add hicolor-icon-theme BuildRequires: was brought in implicit by
  some other dependency before. We need it for %%icon_theme_cache_*
  macros.
- Add gobject-introspection BuildRequires: not a real dependency
  for the build, but it brings in the typelib() dependency
  generator.
- Drop alacarte-no-settings.menu.patch: fixed upstram.
- Rebase alacarte-support-exo-desktop-item-edit.patch.
* Sat Nov  5 2011 gber@opensuse.org
- Added alacarte-support-exo-desktop-item-edit.patch in order to
  support exo-desktop-item-edit as an alternative to
  gnome-desktop-item-edit (bnc#728482)
* Wed Oct 19 2011 badshah400@gmail.com
- Added desktop menu categories to make alacarte appear
  categorised as "Accessories" rather than "Other" (bnc#714333)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Thu Aug 18 2011 dimstar@opensuse.org
- Replace gnome-menus-devel BuildRequires with
  pkgconfig(libgnome-menu) to help the build find the correct
  version of gnome-menus.
* Fri Jul 22 2011 vuntz@opensuse.org
- Add alacarte-no-settings.menu.patch: do not try to edit
  settings.menu, as the file got removed in GNOME 3.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Sep 15 2010 vuntz@opensuse.org
- Update to version 0.13.2:
  + Build against python 2.7
  + Updated translatins.
- Drop alacarte-0.13.1-python27.patch: fixed upstream.
* Mon Sep  6 2010 coolo@novell.com
- Add alacarte-0.13.1-python27.patch: support python 2.7.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 0.13.1:
  + bgo#596098, i18n initialization problem
  + Updated translations.
- Remove en@shaw translations on 11.2 and earlier.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update the way we remove the bem locale for old versions of
  openSUSE.
* Mon Sep 28 2009 dimstar@opensuse.org
- Update to version 0.12.4:
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 0.12.3:
  + Set the translation domain to GtkBuilder
- Changes from version 0.12.2:
  + Use the display name from X-GNOME-FullName when possible
* Fri Aug 14 2009 vuntz@novell.com
- Fix packaging bug: icons are not directories.
* Wed Aug 12 2009 dominique-obs@leuenberger.net
- Define new python macros on openSUSE <= 11.1.
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Tue May  5 2009 vuntz@novell.com
- Update to version 0.12.1:
  + Generate the ChangeLog from git-log
  + Drop libglade dependency
- Remove gnome-common BuildRequires.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 0.11.10:
  + Updated translations.
- Remove AutoReqProv: it's default now.
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun Feb 22 2009 vuntz@novell.com
- Update to version 0.11.9:
  + Remove libgnomeui dependency
  + Updated translations
- Change BuildRequires/Requires on python-gnome to python-gtk.
- Disable alacarte_system_edit_mode.patch and mark it as needing a
  rebase.
* Tue Feb  3 2009 mboman@suse.de
- Update to version 0.11.8:
  + Work properly when pygobject is not installed in a default
    directory
  + Translation updates
- Disable alacarte_system_edit_mode.patch since it needs rebasing.
- Do not require python twice.
* Tue Jan 27 2009 lmedinas@gmail.com
- Update to version 0.11.7:
  + Port to GIO
  + Print better messages when checking for Python libraries
  + Updated translations.
* Sat Jan 17 2009 sreeves@suse.de
- Rebase and reapply alacarte_system_edit_mode patch
* Fri Oct 24 2008 vuntz@novell.com
- Requires python-gnome-menus, so that it actually works.
* Tue Sep 23 2008 maw@suse.de
- Update to version 0.11.6:
  + Install theme icons in a more correct manner
  + Deal with python 2.6
  + Updated translations.
* Thu Sep 11 2008 jpr@novell.com
- Fix build for python 2.6 with alacarte-python-2.6.patch
* Sun Apr 13 2008 sreeves@suse.de
- Add alacarte_system_edit_mode.patch - expand the individual user only
  menu editing capability of alacarte to provide the system administrator
  with system wide menu editing.
* Tue Mar 11 2008 vuntz@suse.de
- Update to version 0.11.5:
  + Fix exception on first open of context menu.
  + Updated translations.
* Tue Mar  4 2008 maw@suse.de
- Update to version 0.11.4:
  + Lots of bugs fixed
  + Updated translations.
* Wed Aug  8 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Wed May  9 2007 pgajdos@suse.cz
- removed gnome-icon-theme from Requires and BuildRequires
  [#247450]
* Thu Mar  8 2007 sbrabec@suse.cz
- Removed obsolete hicolor icon symlink (#248676).
* Tue Feb 27 2007 maw@suse.de
- Update to version 0.11.3.
  * Add back support for System menu
  * remove preferences/administration editing
  * fix goofy bugs
  * respond to show/hide immediately
  * use gnome-desktop-item-edit for all menu and item editing
* Mon Jan 22 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Mon Jan  8 2007 sreeves@suse.de
- upgrade to 0.10.3.  Upstream version now includes current patches.
  This version is needed as part of the work on Fate#301648 for sp1.
* Fri Nov 17 2006 sreeves@suse.de
- Fix for 220300 - wrong gettext init breaks translations
  remove invalid category entry
* Wed Oct  4 2006 jhargadon@suse.de
- added gnome-menus, python-gnome, python-xml, and %%py_requires
  requires to the specfile for bug #207888
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 0.10.1
- lots of small fixes
* Mon Sep 25 2006 ro@suse.de
- accept python-2.5 and move python files to /usr
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 0.10.0
- fix crashed caused by new gnome-menus
- potentially fix crash on solaris
- make help button and F1 work
- translation updates.
* Mon Sep 11 2006 jhargadon@suse.de
- added missing directory ownerships to the specfile
* Thu Aug 31 2006 rodrigo@suse.de
- Initial package submitted.
